@@ -12,6 +12,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from typing import List
+
+from sqlalchemy.orm.exc import NoResultFound
+
 from eva.catalog.models.base_model import BaseModel
 
 
@@ -23,3 +27,10 @@ class BaseService:
 
     def __init__(self, model: BaseModel):
         self.model = model
+
+    def get_all_entries(self) -> List:
+        try:
+            entries = self.model.query.all()
+            return [entry.as_dataclass() for entry in entries]
+        except NoResultFound:
+            return []
