@@ -25,10 +25,12 @@ EVA_ROOT_DIR = Path(eva.__file__).parent.parent
 # We can revisit it later
 EVA_DEFAULT_DIR = Path.home() / ".eva" / str(VERSION)
 EVA_DATASET_DIR = "eva_datasets"
-EVA_UPLOAD_DIR = "tmp"
 EVA_CONFIG_FILE = "eva.yml"
 UDF_DIR = "udfs"
 CATALOG_DIR = "catalog"
 INDEX_DIR = "index"
+CACHE_DIR = "cache"
 DATASET_DATAFRAME_NAME = "dataset"
 DB_DEFAULT_URI = "sqlite:///{}/eva_catalog.db".format(EVA_DEFAULT_DIR.resolve())
+S3_DOWNLOAD_DIR = "s3_downloads"
+TMP_DIR = "tmp"
