@@ -12,6 +12,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
+
 import pandas as pd
 
 from eva.catalog.catalog_manager import CatalogManager
@@ -28,14 +30,12 @@ class DropExecutor(AbstractExecutor):
     def __init__(self, node: DropPlan):
         super().__init__(node)
 
-    def validate(self):
-        pass
-
-    def exec(self):
+    def exec(self, *args, **kwargs):
         """Drop table executor"""
         catalog_manager = CatalogManager()
-        if len(self.node.table_infos) > 1:
-            logger.exception("Drop supports only single table")
+
+        assert len(self.node.table_infos) == 1, "Drop supports only single table"
+
         table_info: TableInfo = self.node.table_infos[0]
 
         if not catalog_manager.check_table_exists(
@@ -49,21 +49,20 @@ class DropExecutor(AbstractExecutor):
                 logger.exception(err_msg)
                 raise ExecutorError(err_msg)
 
-        try:
-            table_obj = catalog_manager.get_table_catalog_entry(
-                table_info.table_name, table_info.database_name
-            )
-            storage_engine = StorageEngine.factory(table_obj)
-        except RuntimeError as err:
-            raise ExecutorError(str(err))
+        table_obj = catalog_manager.get_table_catalog_entry(
+            table_info.table_name, table_info.database_name
+        )
+        storage_engine = StorageEngine.factory(table_obj)
+
         storage_engine.drop(table=table_obj)
 
-        success = catalog_manager.delete_table_catalog_entry(table_obj)
+        for col_obj in table_obj.columns:
+            for cache in col_obj.dep_caches:
+                catalog_manager.drop_udf_cache_catalog_entry(cache)
 
-        if not success:
-            err_msg = "Failed to drop {}".format(table_info)
-            logger.exception(err_msg)
-            raise ExecutorError(err_msg)
+        assert catalog_manager.delete_table_catalog_entry(
+            table_obj
+        ), "Failed to drop {}".format(table_info)
 
         yield Batch(
             pd.DataFrame(
