@@ -12,13 +12,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Generator, Iterator
+from typing import Iterator
 
 from eva.executor.abstract_executor import AbstractExecutor
-from eva.executor.executor_utils import ExecutorError, apply_project
+from eva.executor.executor_utils import apply_project
 from eva.models.storage.batch import Batch
 from eva.plan_nodes.project_plan import ProjectPlan
-from eva.utils.logging_manager import logger
 
 
 class ProjectExecutor(AbstractExecutor):
@@ -28,20 +27,10 @@ class ProjectExecutor(AbstractExecutor):
         super().__init__(node)
         self.target_list = node.target_list
 
-    def validate(self):
-        pass
+    def exec(self, *args, **kwargs) -> Iterator[Batch]:
+        child_executor = self.children[0]
+        for batch in child_executor.exec(**kwargs):
+            batch = apply_project(batch, self.target_list)
 
-    def exec(self, **kwargs) -> Iterator[Batch]:
-        try:
-            child_executor = self.children[0]
-            for batch in child_executor.exec(**kwargs):
-                batch = apply_project(batch, self.target_list)
-
-                if not batch.empty():
-                    yield batch
-        except Exception as e:
-            logger.error(e)
-            raise ExecutorError(e)
-
-    def __call__(self, **kwargs) -> Generator[Batch, None, None]:
-        yield from self.exec(**kwargs)
+            if not batch.empty():
+                yield batch
