@@ -32,10 +32,7 @@ class SampleExecutor(AbstractExecutor):
         super().__init__(node)
         self._sample_freq = node.sample_freq.value
 
-    def validate(self):
-        pass
-
-    def exec(self) -> Iterator[Batch]:
+    def exec(self, *args, **kwargs) -> Iterator[Batch]:
         child_executor = self.children[0]
 
         current = 0
