@@ -44,6 +44,10 @@ class Response:
         obj = PickleSerializer.deserialize(data)
         return obj
 
+    def as_df(self):
+        assert self.batch is not None, "Response is empty"
+        return self.batch.frames
+
     def __str__(self):
         if self.query_time is not None:
             return (
