@@ -14,3 +14,15 @@
 # limitations under the License.
 class CatalogError(Exception):
     pass
+
+
+class UDFIODefinitionError(Exception):
+    pass
+
+
+class DatasetFileNotFoundError(Exception):
+    def __init__(
+        self,
+        message="The dataset file could not be found. Please verify that the file exists in the specified path.",
+    ):
+        super().__init__(message)
