@@ -24,8 +24,8 @@ from eva.expression.constant_value_expression import ConstantValueExpression
 from eva.expression.tuple_value_expression import TupleValueExpression
 from eva.models.storage.batch import Batch
 from eva.parser.types import ParserOrderBySortType
-from eva.planner.limit_plan import LimitPlan
-from eva.planner.orderby_plan import OrderByPlan
+from eva.plan_nodes.limit_plan import LimitPlan
+from eva.plan_nodes.orderby_plan import OrderByPlan
 
 
 class LimitExecutorTest(unittest.TestCase):
