@@ -16,6 +16,7 @@ import unittest
 
 import numpy as np
 import pandas as pd
+import pytest
 
 from eva.expression.abstract_expression import ExpressionType
 from eva.expression.aggregation_expression import AggregationExpression
@@ -36,6 +37,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(1, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_last(self):
         columnName = TupleValueExpression(col_name=0)
@@ -46,6 +48,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(3, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_segment(self):
         columnName = TupleValueExpression(col_name=0)
@@ -56,6 +59,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertTrue((np.array([1, 2, 3]) == batch.frames.iloc[0][0]).all())
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_sum(self):
         columnName = TupleValueExpression(col_name=0)
@@ -66,6 +70,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(6, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_count(self):
         columnName = TupleValueExpression(col_name=0)
@@ -76,6 +81,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(3, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_avg(self):
         columnName = TupleValueExpression(col_name=0)
@@ -86,6 +92,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(2, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_min(self):
         columnName = TupleValueExpression(col_name=0)
@@ -96,6 +103,7 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(1, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
 
     def test_aggregation_max(self):
         columnName = TupleValueExpression(col_name=0)
@@ -106,3 +114,11 @@ class AggregationExpressionsTest(unittest.TestCase):
         tuples = Batch(pd.DataFrame({0: [1, 2, 3], 1: [2, 3, 4], 2: [3, 4, 5]}))
         batch = aggr_expr.evaluate(tuples, None)
         self.assertEqual(3, batch.frames.iloc[0][0])
+        self.assertNotEqual(str(aggr_expr), None)
+
+    def test_aggregation_incorrect_etype(self):
+        incorrect_etype = 100
+        columnName = TupleValueExpression(col_name=0)
+        aggr_expr = AggregationExpression(incorrect_etype, columnName, columnName)
+        with pytest.raises(NotImplementedError):
+            str(aggr_expr)
