@@ -20,7 +20,7 @@ from eva.expression.arithmetic_expression import ArithmeticExpression
 from eva.expression.comparison_expression import ComparisonExpression
 from eva.expression.constant_value_expression import ConstantValueExpression
 from eva.expression.expression_utils import (
-    conjuction_list_to_expression_tree,
+    conjunction_list_to_expression_tree,
     contains_single_column,
     extract_range_list_from_comparison_expr,
     extract_range_list_from_predicate,
@@ -182,7 +182,7 @@ class ExpressionUtilsTest(unittest.TestCase):
     def test_and_(self):
         expr1 = self.gen_cmp_expr(10)
         expr2 = self.gen_cmp_expr(20)
-        new_expr = conjuction_list_to_expression_tree([expr1, expr2])
+        new_expr = conjunction_list_to_expression_tree([expr1, expr2])
         self.assertEqual(new_expr.etype, ExpressionType.LOGICAL_AND)
         self.assertEqual(new_expr.children[0], expr1)
         self.assertEqual(new_expr.children[1], expr2)
