@@ -14,9 +14,9 @@
 # limitations under the License.
 
 import asyncio
-import sys
 import time
 import unittest
+from test.markers import windows_skip_marker
 from test.util import create_sample_video, file_remove
 from unittest.mock import MagicMock
 
@@ -24,7 +24,7 @@ import pytest
 
 from eva.catalog.catalog_manager import CatalogManager
 from eva.server.command_handler import handle_request
-from eva.utils.timer import Timer
+from eva.utils.stats import Timer
 
 NUM_FRAMES = 10
 
@@ -33,9 +33,8 @@ class TimerTests(unittest.TestCase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-    @pytest.mark.skipif(sys.platform == "win32", reason="does not run on windows")
+    @windows_skip_marker
     def test_timer(self):
-
         sleep_time = Timer()
         with sleep_time:
             time.sleep(5)
@@ -43,6 +42,7 @@ class TimerTests(unittest.TestCase):
         self.assertTrue(sleep_time.total_elapsed_time < 5.2)
         self.assertTrue(sleep_time.total_elapsed_time > 4.9)
 
+    @pytest.mark.notparallel
     def test_timer_with_query(self):
         CatalogManager().reset()
         video_file_path = create_sample_video(NUM_FRAMES)
